@@ -48,8 +48,8 @@ class Ppos(Module):
             program_version_sign = program_version_sign[2:]
         data = HexBytes(rlp.encode([rlp.encode(int(1000)), rlp.encode(typ), rlp.encode(bytes.fromhex(benifit_address)),
                                     rlp.encode(bytes.fromhex(node_id)), rlp.encode(external_id), rlp.encode(node_name),
-                                    rlp.encode(website), rlp.encode(details), rlp.encode(reward_per),
-                                    rlp.encode(amount), rlp.encode(program_version),
+                                    rlp.encode(website), rlp.encode(details),
+                                    rlp.encode(amount), rlp.encode(reward_per), rlp.encode(program_version),
                                     rlp.encode(bytes.fromhex(program_version_sign)), rlp.encode(bytes.fromhex(bls_pubkey)),
                                     rlp.encode(bytes.fromhex(bls_proof))])).hex()
         return send_obj_transaction(self, data, self.web3.stakingAddress, pri_key, transaction_cfg)
